@@ -1,5 +1,5 @@
 package IRC::Indexer;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 ## stub! for now ..
 
@@ -36,16 +36,20 @@ IRC::Indexer - IRC server stats collection via POE
 
 =head1 DESCRIPTION
 
-A set of modules and utilities useful for trawling IRC networks, 
-collecting information, and exporting it to portable formats for use in 
-Web frontends and other applications.
+IRC::Indexer is a set of modules and utilities useful for trawling IRC 
+networks, collecting information, and exporting it to portable formats 
+for use in Web frontends and other applications.
 
 L<ircindexer-server-json> serves as an example of how to use the trawler 
 system to index IRC networks; it is usable as-is to trawl sets of IRC 
 servers belonging to configured networks and serve JSON-serialized 
-network stats via HTTP. This could be used directly to build an IRC 
-trawling/indexing Web application in a language of your choice, for 
-example.
+network stats via HTTP.
+
+L<ircindexer-server-json> "should be" fairly scalable; this could be 
+used directly to build an IRC trawling/indexing Web application in a 
+language of your choice, for example (or just grab data at intervals 
+and spit out some graphs for a network or two, see B<examples/> in the 
+distribution).
 
 L<ircindexer-single> can be used to trawl a single server in one shot, 
 exporting to YAML, JSON, or Perl.
